scikit-learn examples adapted for scikit-hubness — scikit-hubness 0.21.0 documentation

# scikit-learn examples adapted for scikit-hubness

Examples concerning using `skhubness.neighbors` as drop-in replacement for `sklearn.neighbors`.

These examples are taken from scikit-learn and demonstrate the ease of transition from `sklearn.neighbors` to `skhubness.neighbors`. You will find that many examples require no more than modifying an import line, and/or adding one argument when instantiating an estimator.

Note, that these examples are not intended to demonstrate improved learning performance due to hubness reduction (the data are rather low-dimensional).

Nearest Neighbors regression

Nearest Centroid Classification

Nearest Neighbors Classification

Dimensionality Reduction with Neighborhood Components Analysis

Face completion with a multi-output estimators

Comparing Nearest Neighbors with and without Neighborhood Components Analysis

Manifold learning on handwritten digits: Locally Linear Embedding, Isomap…

Gallery generated by Sphinx-Gallery